import { RabbitSubscribe } from '@golevelup/nestjs-rabbitmq';
import { Controller, Inject } from '@nestjs/common';
import { WINSTON_MODULE_PROVIDER } from 'nest-winston';
import { Logger } from 'winston';
import { level } from './logger/level.enum';
import loggerOptions from './logger/logger';

@Controller()
export class AuthController {
  constructor(
    @Inject(WINSTON_MODULE_PROVIDER) private readonly logger: Logger,
  ) {}

  @RabbitSubscribe({
    name: 'loggingAuthCreateCrit',
  })
  public async authCreatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.crit, 'critical', 'create'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthDeleteCrit',
  })
  public async authDeletedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.crit, 'critical', 'delete'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthUsernameAddWarning',
  })
  public async authUsernameAddedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'username-add'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthUsernameDeleteWarning',
  })
  public async authUsernameDeletedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'username-delete'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthPasswordUpdateWarning',
  })
  public async authPasswordUpdatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'password-update'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthUsernameUpdateWarning',
  })
  public async authUsernameUpdatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'username-update'),
    );
    this.logger.warning(JSON.parse(message));
  }
}
